/*
 * First we sort the numbers in increasing order. This can be done in O(n log n) time.
 * Then, maintain two pointer i and j, where initially i=0, j=N-1.
 * We want to maintain the invariant that for any i, the j satisfying:
 * 1. A[i]+A[j]<=M
 * 2. j>i
 * 3. A[i]+A[j+1]>M
 *
 * Suppose for some i and j, the above invariant holds. For i'=i+1, consier j' to be the one
 * that satisfyint the above conditions. It is possible that j' does not exist. If this is the case,
 * then for any i''>=i', there is no such j'. If there is still j' satisfies the conditions, then it is
 * easy to see that j'<=j.
 *
 * Observe that the answer for the problem is the sum of (j-i) for all i and j satisfy the invariant.
 *
 * So, it is sufficient to iterate i from 0 to N-1 while maintaining j. Since i can only increase and
 * j can only decrease, the total elements visited by i and j are upper bounded by O(N). So the time complexity is
 * O(N) for this step. See solve() for details.
 *
 * In total, this problem can be solved in O(n log n) time. Note that if the input is already sorted, we can solve
 * the problem in O(n) time.
 *
 */
#include <cstdio>
#include <algorithm>

using namespace std;

int N, M;

int A[100010];

void input()
{
	scanf("%d%d", &N, &M);
	for (int i=0; i<N; i++)
	{
		scanf("%d", A+i);
	}
}

long long solve()
{
	long long res=0;
	sort(A, A+N);
	for (int i=0,j=N-1;i<N;i++)
	{
		for (;i<j && A[i]+A[j]>M;j--)
		{
		}
		if (j>i)
		{
			res+=(j-i);
		}
	}
	return res;
}

int main()
{
	int T;
	scanf("%d", &T);
	for (int t=0;t<T;t++)
	{
		input();
		printf("%lld\n", solve());
	}
	return 0;
}

