#include <cstdio>
#include <cstring>
#include <algorithm>

struct Node
{
	Node *L, *R;
	int left, right;
	int max;
	int min;
	int rev;

	void pushUp()
	{
		if (left==right)
			return;
		L->pushDown();
		R->pushDown();
		max=std::max(L->max, R->max);
		min=std::min(L->min, R->min);
	}
	void pushDown()
	{
		if (rev)
		{
			if (L)
				L->rev ^= 1;
			if (R)
				R->rev ^= 1;
			std::swap(max, min);
			max=-max;
			min=-min;
			rev = 0;
		}
	}
	int mid()
	{
		return (left+right)/2;
	}
};

Node buf[100000*5];
int C;

struct SegTree
{
	Node *root;
	SegTree(int left, int right, int arr[])
	{
		C=0;
		root=build(left, right, arr);
	}

	Node* build(int left,int right,int arr[])
	{
		Node *r=&buf[C++];
		r->left=left;
		r->right=right;
		r->rev=0;
		if (left==right)
		{
			r->L=r->R=NULL;
			r->max=r->min=arr[left];
		}
		else
		{
			int mid=(left+right)/2;
			r->L=build(left, mid, arr);
			r->R=build(mid+1, right, arr);
		}
		r->pushUp();
		return r;
	}
	void update(Node *root, int left, int right)
	{
		root->pushDown();
		if (root->left==left && root->right==right)
		{
			root->rev ^= 1;
			return;
		}
		int mid=root->mid();
		if (right<=mid)
		{
			update(root->L, left, right);
		}
		else if (left>mid)
		{
			update(root->R, left, right);
		}
		else
		{
			update(root->L, left, mid);
			update(root->R, mid+1, right);
		}
		root->pushUp();
	}
	int query(Node *root, int left, int right)
	{
		root->pushDown();
		if (root->left==left && root->right==right)
		{
			return root->min;
		}
		int mid=root->mid();
		if (right<=mid)
		{
			return query(root->L, left, right);
		}
		else if (left>mid)
		{
			return query(root->R, left, right);
		}
		else
		{
			return std::min(query(root->L, left, mid),
					query(root->R, mid+1, right));
		}
	}
};

int arr[100010];
int N,M;

void input()
{
	scanf("%d%d",&N,&M);
	for (int i=0;i<N;i++) scanf("%d",arr+i);
}

void work()
{
	SegTree tree(0, N-1, arr);
	char tmp[16];
	for (int i=0;i<M;i++)
	{
		scanf("%s",tmp);
		int p, q;
		scanf("%d%d",&p,&q);
		p--;
		q--;
		if (tmp[0]=='U')
		{
			tree.update(tree.root, p, q);
		}
		else
		{
			printf("%d\n",tree.query(tree.root, p, q));
		}
	}
}

int main()
{
	int T;
	scanf("%d",&T);
	for (int t=0;t<T;t++)
	{
		input();
		work();
	}
	return 0;
}

