/*
 * The key observation is:
 * 1. The number of columns is small (<=16).
 * 2. Once the operation for the first row is fixed, in order to turn all the lights on,
 * the operations for the subsequent rows are also fixed.
 *
 * So, it is sufficient to enumerate the operation for the first row. The number of enumeration
 * is at most 2^16. Then we scan row by row to fix the other operations, and record the optimal.
 * This can be done in O(m * n) time. An optimization is to use 16 bits to denote a row, and by some
 * precalculation, we may decrease the time to O(n).
 */
#include <cstdio>
#include <algorithm>

using namespace std;

int next[1 << 16];
int operation[1 << 16];
int rowOperation[1 << 16];

void init(int n)
{
	for (int i=0;i<(1 << n);i++)
	{
		next[i]=0;
		operation[i]=0;
		rowOperation[i]=0;
		for (int j=0;j<n;j++)
		{
			if ((i >> j) & 1)
			{
				if (j-1>=0)
				{
					rowOperation[i] ^= (1 << (j-1));
				}
				if (j+1<n)
				{
					rowOperation[i] ^= (1 << (j+1));
				}
				rowOperation[i] ^= (1 << j);
			}
			else
			{
				next[i]+=1 << j;
				operation[i]++;
			}
		}
	}
}

int check(int firstOperation,int num, int n,int m, int initial[])
{
	int arr[100];
	int lastState=rowOperation[firstOperation] ^ initial[0];
	int cnt=num;
	int lastOperation=firstOperation;
	for (int i=1;i<n;i++)
	{
		int currentOperation=next[lastState];
		cnt+=operation[lastState];
		lastState=initial[i] ^ rowOperation[currentOperation] ^ lastOperation;
		lastOperation=currentOperation;
	}
	if (lastState==((1 << m)-1))
		return cnt;
	return -1;
}

int solve(int n,int m,int initial[])
{
	int cnt=-1;
	for (int i=0;i<(1 << m);i++)
	{
		int firstOperation=0;
		for (int j=0;j<m;j++)
		{
			if ((i >> j) & 1)
			{
				firstOperation++;
			}
		}
		int current=check(i, firstOperation, n, m, initial);
		if (current!=-1)
		{
			if (cnt==-1 || cnt>current)
				cnt=current;
		}
	}
	return cnt;
}

int initial[100];
int N, M;

void input()
{
	scanf("%d%d", &N, &M);
	for (int i=0;i<N;i++)
	{
		char tmp[32];
		scanf("%s",tmp);
		initial[i]=0;
		for (int j=0;j<M;j++)
		{
			initial[i]+=(tmp[j]-'0')*(1 << (M-1-j));
		}
	}
}

int main()
{
	int T;
	scanf("%d",&T);
	for (int t=0;t<T;t++)
	{
		input();
		init(M);
		printf("%d\n", solve(N, M, initial));
	}
	return 0;
}

